#ifndef _GLOBAL_ARENA
#define _GLOBAL_ARENA

#include "BumpAlloc.h"
#include "Array.h"

// Global bump arena
extern BumpArena g_arena;

void*  BG_alloc(usize size);
int    BG_resizeable(void* ptr);
Result BG_resize(usize size);
Result BG_free();

#endif /* _GLOBAL_ARENA */
