#include "GlobalArena.h"

BumpArena g_arena = NULL;

void*
BG_alloc(usize size) {
    return B_alloc(g_arena, size);
}

int
BG_resizeable(void* ptr) {
    return B_resizeable(g_arena, ptr);
}

Result
BG_resize(usize size) {
    return B_resize(g_arena, size);
}

Result
BG_free() {
    return B_free(g_arena);
}
